pub struct GatingPolicy { /* private fields */ }Expand description
Innovation gating policy.
The normalised innovation squared is χ²-distributed with as many degrees of freedom as the observation has elements when the model holds. A value far in the tail is more likely a fault than a surprise.
Implementations