#[non_exhaustive]pub enum RejectionReason {
Invalid,
Stale,
OutOfOrder,
ImplausibleJump {
implied_speed: Speed,
},
Improbable {
normalised_innovation_squared: f64,
},
}Expand description
Observation rejection reason.
#[non_exhaustive]; match with a wildcard arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Invalid
Marked invalid by the source.
Stale
Older than the use case accepts.
OutOfOrder
Timestamped before an already accepted observation and not applicable retroactively: late observations are rejected by policy, or it is older than the policy or history allows.
ImplausibleJump
Implied speed exceeds the plausible maximum.
Improbable
Innovation outside the estimator’s gate.