pub struct ErrorEllipse { /* private fields */ }Expand description
1σ horizontal position error ellipse.
Semi-axes and true direction of the major axis of a 2 × 2 covariance. Scale axes by 2.45 for 95 %, by 1.18 for an equal-probability circle when the axes are nearly equal.
Implementations
Sourceimpl ErrorEllipse
impl ErrorEllipse
Sourcepub fn from_covariance(north: f64, north_east: f64, east: f64) -> Option<Self>
pub fn from_covariance(north: f64, north_east: f64, east: f64) -> Option<Self>
Ellipse of a north/east covariance, m².
None unless a valid covariance: finite, non-negative variances,
|correlation| ≤ 1.
Sourcepub fn new(
semi_major: Distance,
semi_minor: Distance,
orientation: TrueCourse,
) -> Result<Self>
pub fn new( semi_major: Distance, semi_minor: Distance, orientation: TrueCourse, ) -> Result<Self>
Ellipse from semi-axes and major-axis direction.
Errors
crate::error::KernelError::OutOfRange for a negative axis or minor >
major.
Sourcepub fn circular(radius: Distance) -> Self
pub fn circular(radius: Distance) -> Self
Circle of the given radius; a negative radius is taken by magnitude.
Sourcepub const fn semi_major(&self) -> Distance
pub const fn semi_major(&self) -> Distance
1σ semi-major axis.
Sourcepub const fn semi_minor(&self) -> Distance
pub const fn semi_minor(&self) -> Distance
1σ semi-minor axis.
Sourcepub fn orientation(&self) -> TrueCourse
pub fn orientation(&self) -> TrueCourse
True direction of the major axis, in [0°, 180°) (axes have no sense).
Sourcepub fn equivalent_radius(&self) -> Distance
pub fn equivalent_radius(&self) -> Distance
Radius of the circle of equal area, for displays with no room for an ellipse.