Distance

Struct Distance 

pub struct Distance(/* private fields */);
Distance, stored in nautical miles.

Signed: e.g. along-track distance is negative before the start of a leg. Functions requiring a positive distance check it.

Implementations

Source

impl Distance

pub const ZERO: Self

Zero.

pub fn from_nautical_miles(value: f64) -> Result<Self>

From nautical miles.

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_cables(value: f64) -> Result<Self>

From cables (10 per NM).

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_metres(value: f64) -> Result<Self>

From metres.

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_kilometres(value: f64) -> Result<Self>

From kilometres.

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_feet(value: f64) -> Result<Self>

From feet (e.g. charted heights of lights).

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_fathoms(value: f64) -> Result<Self>

From fathoms.

Errors

KernelError::NotFinite for NaN or infinity.

pub fn from_arc_minutes(value: f64) -> Result<Self>

From minutes of arc of a great circle (1′ = 1 NM).

Errors

KernelError::NotFinite for NaN or infinity.

pub const fn nautical_miles(self) -> f64

Nautical miles.

pub fn cables(self) -> f64

Cables.

pub fn metres(self) -> f64

Metres.

pub fn kilometres(self) -> f64

Kilometres.

pub fn feet(self) -> f64

Feet.

pub fn abs(self) -> Self

Absolute value.

pub fn is_negative(self) -> bool

Whether negative.

pub fn time_at(self, speed: Speed) -> Result<Duration>

Time to cover this distance at speed.

Errors

KernelError::Indeterminate if the speed is zero or of opposite sign.